@@ -541,6 +541,25 @@ class TreePartVoice(object):
         # else:
         #     warnings.warn('ties of chords in {} already adjoined. No action took place.'.format(self))
 
+    def break_beams(self):
+        def _get_relevant_beams(chord):
+            return [beam for beam in chord.get_children_by_type(Beam) if
+                    beam.number > 1 and beam.value == 'continue']
+
+        if self.break_beam_32:
+            for beat in self.beats:
+                try:
+                    quaver_positioned_chord = [chord for chord in beat.chords if chord.offset % 1 == 0.5][0]
+                    previous_chord = beat.chords[beat.chords.index(quaver_positioned_chord) - 1]
+                    for beam in _get_relevant_beams(quaver_positioned_chord):
+                        beam.value = 'begin'
+                    for beam in _get_relevant_beams(previous_chord):
+                        beam.value = 'end'
+                except IndexError:
+                    pass
+        else:
+            pass
+
     def clear_zero_heads_tails(self):
         for chord in self.chords:
             if chord.quarter_duration == 0 and (chord._head or chord._tail):
@@ -570,25 +589,6 @@ class TreePartVoice(object):
                         grouping_list.append(1)
             return grouping_list
 
-        def _set_break_beams():
-            def _get_relevant_beams(chord):
-                return [beam for beam in chord.get_children_by_type(Beam) if
-                        beam.number > 1 and beam.value == 'continue']
-
-            if self.break_beam_32:
-                for gr in grouped_chords:
-                    try:
-                        quaver_positioned_chord = [chord for chord in gr if chord.offset == 0.5][0]
-                        previous_chord = gr[gr.index(quaver_positioned_chord) - 1]
-                        for beam in _get_relevant_beams(quaver_positioned_chord):
-                            beam.value = 'begin'
-                        for beam in _get_relevant_beams(previous_chord):
-                            beam.value = 'end'
-                    except IndexError:
-                        pass
-            else:
-                pass
-
         def _set_beams():
 
             global begin_beam, continue_end_beam
@@ -643,7 +643,6 @@ class TreePartVoice(object):
             grouping_list = _generate_grouping_list()
             grouped_chords = self._group_beats(grouping_list)
             _set_beams()
-            _set_break_beams()
         else:
             raise NotImplementedError('group_beams with values other than None')
 
@@ -1343,6 +1342,10 @@ class TreePart(timewise.Part):
         for tree_part_voice in self.tree_part_voices:
             tree_part_voice.adjoin_rests()
 
+    def break_beams(self):
+        for tree_part_voice in self.tree_part_voices:
+            tree_part_voice.break_beams()
+
     # def adjoin_rests_in_beat(self):
     #     for voice in self.voices:
     #         voice.adjoin_rests_in_beat()
@@ -1457,6 +1460,8 @@ class TreePart(timewise.Part):
 
             self.group_beams()
 
+            self.break_beams()
+
             self.implement_flags_3()
 
             self.chords_to_notes()
