@@ -1,5 +1,5 @@
 import os
-from fractions import Fraction
+from quicktions import Fraction
 from itertools import permutations
 from unittest import TestCase
 
@@ -32,7 +32,8 @@ def _generate_test_32_groups():
         11: _permute_without_duplicates([4, 1, 1, 1, 1]),
         12: _permute_without_duplicates([5, 1, 1, 1]),
         13: _permute_without_duplicates([6, 1, 1]),
-        14: _permute_without_duplicates([7, 1])
+        14: _permute_without_duplicates([7, 1]),
+        15: _permute_without_duplicates([3, 3, 2]),
 
     }
 
@@ -191,7 +192,9 @@ class Test(TestCase):
                          [1, 1, 1, 1, 4]],
                     12: [[5, 1, 1, 1], [1, 5, 1, 1], [1, 1, 5, 1], [1, 1, 1, 5]],
                     13: [[6, 1, 1], [1, 6, 1], [1, 1, 6]],
-                    14: [[7, 1], [1, 7]]}
+                    14: [[7, 1], [1, 7]],
+                    15: [[3, 3, 2], [3, 2, 3], [2, 3, 3]]
+                    }
         self.assertEqual(expected, actual)
 
     def test_get_32_groups(self):
@@ -249,7 +252,7 @@ class Test(TestCase):
     def test_all_possible_32s(self):
         self.score.break_beam_32 = True
         self.score.set_time_signatures(times={1: (1, 4)})
-        keys = list(range(1, 15))
+        keys = list(range(1, 16))
         all_durations = flatten(convert_32_groups_to_quarter_durations(get_32_groups(keys)))
         sf = SimpleFormat(quarter_durations=all_durations)
 
@@ -259,3 +262,22 @@ class Test(TestCase):
         self.score.to_partwise()
         self.score.write(xml_path)
         TestScore().assert_template(xml_path)
+
+    def test_beam_break_with_quantization(self):
+        quarter_durations = [Fraction(2, 1), Fraction(1, 1), Fraction(3, 2), Fraction(5, 2), Fraction(1, 1),
+                             Fraction(2, 1), Fraction(3, 1), Fraction(1, 1), Fraction(3, 2), Fraction(1, 2),
+                             Fraction(4, 15), Fraction(2, 5), Fraction(1, 3), Fraction(8, 15), Fraction(8, 45),
+                             Fraction(2, 9), Fraction(4, 15), Fraction(16, 75), Fraction(8, 25), Fraction(4, 15),
+                             Fraction(3, 5), Fraction(1, 2), Fraction(2, 5), Fraction(1, 2), Fraction(1, 3),
+                             Fraction(2, 5), Fraction(4, 15), Fraction(16, 75), Fraction(4, 15), Fraction(8, 25),
+                             Fraction(8, 15), Fraction(2, 3)]
+
+        self.score.break_beam_32 = True
+        self.score.forbidden_divisions = [5, 6, 7]
+        sf = SimpleFormat(quarter_durations=quarter_durations)
+        sf.to_stream_voice().add_to_score(self.score)
+        xml_path = path + '_beam_break_with_quantization.xml'
+        self.score.finish()
+        self.score.to_partwise()
+        self.score.write(xml_path)
+        TestScore().assert_template(xml_path)
